@@ -1,17 +1,12 @@
 /*
- * Copyright (C) 2013, 2014, 2016  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * Permission to use, copy, modify, and/or distribute this software for any
- * purpose with or without fee is hereby granted, provided that the above
- * copyright notice and this permission notice appear in all copies.
+ * This Source Code Form is subject to the terms of the Mozilla Public
+ * License, v. 2.0. If a copy of the MPL was not distributed with this
+ * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  *
- * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
- * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY SPECIAL, DIRECT,
- * INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
- * LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
- * OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THIS SOFTWARE.
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /*
@@ -84,7 +79,7 @@
 #include <netdb.h>
 #include <pthread.h>
 #include <signal.h>
-#include <stdint.h>
+#include <inttypes.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -209,7 +204,7 @@ uint64_t xscount;				/* sent counters */
 uint64_t xrcount;				/* received counters */
 
 /*
- * statictics counters and accumulators
+ * statistics counters and accumulators
  */
 
 uint64_t recverr, tooshort, locallimit;		/* error counters */
@@ -2361,7 +2356,7 @@ main(const int argc, char * const argv[])
 	(void) pthread_cancel(sender);
 	(void) pthread_cancel(receiver);
 
-	/* main statictics */
+	/* main statistics */
 	printf("connect: %llu, sent: %llu, received: %llu\n",
 	       (unsigned long long) xccount,
 	       (unsigned long long) xscount,
