@@ -1,9 +1,12 @@
 /*
- * Copyright (C) 2000, 2001, 2004, 2005, 2007, 2016  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ *
+ * See the COPYRIGHT file distributed with this work for additional
+ * information regarding copyright ownership.
  */
 
 /* $Id: ondestroy.c,v 1.16 2007/06/19 23:47:17 tbox Exp $ */
@@ -39,11 +42,10 @@ isc_ondestroy_register(isc_ondestroy_t *ondest, isc_task_t *task,
 	REQUIRE(VALID_ONDESTROY(ondest));
 	REQUIRE(task != NULL);
 	REQUIRE(eventp != NULL);
+	REQUIRE((*eventp) != NULL);
 
 	theevent = *eventp;
 
-	REQUIRE(theevent != NULL);
-
 	isc_task_attach(task, &thetask);
 
 	theevent->ev_sender = thetask;
